function yohkoh_legacy_files, time0, time1, _extra=_extra, $
   ssc=ssc, topurl=topurl, count=count, debug=debug, $
   force_url=force_url
;
;+
;   Name: yohkoh_legacy_files
;
;   Purpose: return Yohkoh Legacy filenames for user input times
;
;   Input Parameters:
;      time0 - time or start of time range
;      time1 - optional end time if range
;     
;   Output:
;       function returns list of files (paths if local else URLs)
; 
;   Keyword Parameters:
;      ssc - if set, default to SSC files
;      count - number of files/urls returned
;      force_url - if set, return URLs even if data is 'local'
;                  (only required at Legacy host sites + URLS desired)
; 
;   History:
;      14-Feb-2005 - S.L.Freeland - hook new SSC-FITS->CoSEC/SSW
;
;-
debug=keyword_set(debug)

deflegacy=get_logenv('YOHKOH_LEGACY')
defssc=get_logenv('YOHKOH_LEGACY_SSC')
force_url=keyword_set(force_url)
case 1 of
   data_chk(topurl,/string):
   keyword_set(ssc) and defssc ne '': topurl=defssc
   file_exist(deflegacy) and (1-force_url): topurl=deflegacy
   else: topurl='http://solar.physics.montana.edu/ylegacy/ssc/'
endcase

case n_params() of
   0: begin 
         box_message,'Need a time or time range...'
         return,''
   endcase
   1: time1=time0
   else:
endcase

tgrid=timegrid(anytim(time0,/utc_int),anytim(time1,/utc_int), $
                      /quiet,/days, /ecs,  /date_only)

retval=''
ndays=n_elements(tgrid)

sdurls=topurl+tgrid+'/'
retval=''  
for i=0,ndays-1 do begin 
   box_message,[systime(),'listing>> ' + sdurls(i)]
   sock_list,sdurls(i),sdlist
   box_message,'converting ' + systime()
   ssfts=where(strpos(sdlist,'.fts') ne -1, fcnt)
   if fcnt gt 0 then begin
      rettmp=sdurls(i)+strarrcompress(strextract(sdlist(ssfts),'HREF="','">'))
      if rettmp(0) ne '' then retval = [temporary(retval),rettmp] else $
          box_message,'Problem with html listing parse...'
   endif else box_message,'No fits files for ' + tgrid(i)
endfor

ssok=where(retval ne '',count)
if count gt 0 then retval=retval(ssok) else retval=retval(0)
if debug then stop,'retval'
return,retval
end



